<?php
/*
Plugin Name: Around this date in the past...
Plugin URI: http://junyent.org/blog/2006/05/20/around-this-date-in-the-past-wordpress-plugin/
Description: It shows entries/posts around this date in the past (if they exist)
Version: 0.6.2
Author: Joan Junyent Tarrida
Contributors: jjunyent, Mike Koepke, Cinefilo
Author URI: http://www.junyent.org/

[ Notas en castellano en la web ]  [  Notes en catala a la web ]

Parameters

	$before = Code will show before links. Defaults to ‘This week last year…: ‘
	$after = Code will show after links. Defaults to ‘’
	$daysbefore = Days' posts that will show before one year ago. By default '3' (3 days before)
	$daysafter = Days' posts that will show after one year ago. By default '3' (3 days after)
	$mode = Select the mode that you want the widget to work. By default '1' (X years ago)
		Mode 1: get posts around this date from X years ago.
		Mode 2: get posts around this date for the last X years.
		Mode 3: get posts around this date since year X.
	$yearsago = It shows “X” years ago posts. By default '1' (1 year). ONLY IF MODE 1 IS SELECTED.
	$lastxyears = It shows posts por the last "X" years. By default '1' (1 year). ONLY IF MODE 2 IS SELECTED.
	$sinceyear = It shows posts since the year "X". By default '2005' (since year 2005). ONLY IF MODE 3 IS SELECTED.
	$limit = Number of posts to retrieve. By default '4'. 
	$none = Text shown when there are no posts. By default 'none'. 

Use

	You can call to function with default parameters:

		<?php around_this_date(); ?>

	Or configure it:

		<?php around_this_date ($before = 'One year ago... ', $after = '<br />', $daysbefore = '3', $daysafter = '3', $mode='1', $yearsago = '1'′,  $limit = '5', $none= 'none'′); ?>
		or
		<?php around_this_date ($before = 'One year ago... ', $after = '<br />', $daysbefore = '3', $daysafter = '3', $mode='2', $lastxyears = '2'′,  $limit = '5', $none= 'none'′′); ?>
		or
		<?php around_this_date ($before = 'One year ago... ', $after = '<br />', $daysbefore = '3', $daysafter = '3', $mode='3', $sinceyear = '2004'′,  $limit = '5', $none= 'none'′′); ?>

License

	This plugin is free software; you can redistribute it and/or modify (without commercial purposes) it under the terms of the Creative Commons License (don't remove credits to author, please)
	You can view the full text of the license here: http://creativecommons.org/licenses/by-nc/2.5/

Changelog
	v.0.6.2 = Fixed a bug when having  &amp; in post's title. Isolated repetitive code in its own function. Changes contributed by Mike Koepke. 
	v.0.6.1 = Fixed bug when having quotes in post's title. Thanks to Mike Koepke for bug repporting and helping with fixing.
	v0.6 = Added 2 new modes, last X years and since year X. 
		Corrected bug in $start_ago and $end_ago.
	v0.5.2 = XHTML valid. Lu�s P�rez (aka Cin�filo)
	v0.5.1 = Now the $yearsago parameter works.
	v0.5.01 = Now the limit option works, for real ;)
	v0.5 = First release. I decided to start on version 0.5 because of preserving version relation with �One year ago� plugin.

Thanks

	Thanks to Borja Fernandez, Chris Goringe and Sven Weidauer for writing their plugins and to Luis P�rez and Mike Koepke for their contributions.
	

	
*/

function around_this_date ( $daysbefore = '3', $daysafter = '3', $mode = '1', $yearsago = '1', $lastxyears= '1', $sinceyear='2006', $limit = '4', $none = 'none') 
{
		
	if ($mode == '1') {  // "classic" mode
	
		$start_ago = (365*$yearsago)+$daysbefore;
		$end_ago = (365*$yearsago)-$daysafter;
		
		get_old_posts( $start_ago, $end_ago, $limit);
	}
	elseif ($mode == '2') { // last x years mode
	
		for($year = 1; $year <= $lastxyears; $year++) {
		
			$start_ago = (365*$year)+$daysbefore;
			$end_ago = (365*$year)-$daysafter;
			
			get_old_posts( $start_ago, $end_ago, $limit);
		}
	}
	elseif ($mode == '3') { // since year x mode
	
		for($year = 1; $year <= (date("Y")-$sinceyear); $year++) {

			$start_ago = (365*$year)+$daysbefore;
			$end_ago = (365*$year)-$daysafter;
			
			get_old_posts( $start_ago, $end_ago, $limit);
		}
	}
}

function get_old_posts( $start_ago, $end_ago, $limit, $none)
{
	global $wpdb;

	$entries = $wpdb->get_results ("SELECT " .
				  "ID, post_title " .
				  "FROM $wpdb->posts " .
				  " WHERE post_status = 'publish' AND (( TO_DAYS( NOW() ) - TO_DAYS( post_date ) ) BETWEEN " . $end_ago . " AND " . $start_ago . ")".
				  " ORDER by 'asc'" .
				  " LIMIT $limit"
					);
							
	print "<ul>";
	if ($entries) {
		$output = ''; // empty the 'output' string
		foreach ($entries as $entry) {
			$title = str_replace('"', '',$entry->post_title);
			$title = htmlspecialchars($title);						
			$output .= '<li><a href="'.get_permalink($entry->ID).'" rel="bookmark" title="Permanent link to '.$title.'">'. htmlspecialchars($entry->post_title) .'</a></li>';
		}
		print "$output";
	}
	else {
		print('<li>' .$none. '</li>');	
	}
	print "</ul>";
}


?>
